@@ -45,6 +45,10 @@ class _ChatButtonData:
         The objects to display.
     buttons : List
         The buttons to display.
+    callback : Callable
+        The callback to execute when the button is clicked.
+    js_on_click : dict | str | None
+        The JavaScript `code` and `args` to execute when the button is clicked.
     """
 
     index: int
@@ -53,6 +57,7 @@ class _ChatButtonData:
     objects: List
     buttons: List
     callback: Callable
+    js_on_click: dict | str | None = None
 
 
 class ChatInterface(ChatFeed):
@@ -114,16 +119,27 @@ class ChatInterface(ChatFeed):
     button_properties = param.Dict(default={}, doc="""
         Allows addition of functionality or customization of buttons
         by supplying a mapping from the button name to a dictionary
-        containing the `icon`, `callback`, and/or `post_callback` keys.
+        containing the `icon`, `callback`, `post_callback`, and/or `js_on_click` keys.
+
         If the button names correspond to default buttons
         (send, rerun, undo, clear), the default icon can be
         updated and if a `callback` key value pair is provided,
         the specified callback functionality runs before the existing one.
+
         For button names that don't match existing ones,
-        new buttons are created and must include a `callback` or `post_callback` key.
+        new buttons are created and must include a
+        `callback`, `post_callback`, and/or `js_on_click` key.
+
         The provided callbacks should have a signature that accepts
         two positional arguments: instance (the ChatInterface instance)
         and event (the button click event).
+
+        The `js_on_click` key should be a str or dict. If str,
+        provide the JavaScript code; else if dict, it must have a
+        `code` key, containing the JavaScript code
+        to execute when the button is clicked, and optionally an `args` key,
+        containing dictionary of arguments to pass to the JavaScript
+        code.
         """)
 
     _widgets = param.Dict(default={}, allow_refs=False, doc="""
@@ -207,6 +223,7 @@ class ChatInterface(ChatFeed):
             name = name.lower()
             callback = properties.get("callback")
             post_callback = properties.get("post_callback")
+            js_on_click = properties.get("js_on_click")
             default_properties = default_button_properties.get(name) or {}
             if default_properties:
                 default_callback = default_properties["_default_callback"]
@@ -222,7 +239,7 @@ class ChatInterface(ChatFeed):
                 callback = self._wrap_callbacks(post_callback=post_callback)(callback)
             elif callback is None and post_callback is not None:
                 callback = post_callback
-            elif callback is None and post_callback is None:
+            elif callback is None and post_callback is None and not js_on_click:
                 raise ValueError(f"A 'callback' key is required for the {name!r} button")
             icon = properties.get("icon") or default_properties.get("icon")
             self._button_data[name] = _ChatButtonData(
@@ -232,6 +249,7 @@ class ChatInterface(ChatFeed):
                 objects=[],
                 buttons=[],
                 callback=callback,
+                js_on_click=js_on_click,
             )
 
         widgets = self.widgets
@@ -300,8 +318,23 @@ class ChatInterface(ChatFeed):
                 )
                 if action != "stop":
                     self._link_disabled_loading(button)
-                callback = partial(button_data.callback, self)
-                button.on_click(callback)
+                if button_data.callback:
+                    callback = partial(button_data.callback, self)
+                    button.on_click(callback)
+                if button_data.js_on_click:
+                    js_on_click = button_data.js_on_click
+                    if isinstance(js_on_click, dict):
+                        if "code" not in js_on_click:
+                            raise ValueError(
+                                f"A 'code' key is required for the {action!r} button's "
+                                "'js_on_click' key"
+                            )
+                        button.js_on_click(
+                            args=js_on_click.get("args", {}),
+                            code=js_on_click["code"],
+                        )
+                    elif isinstance(js_on_click, str):
+                        button.js_on_click(code=js_on_click)
                 self._buttons[action] = button
                 button_data.buttons.append(button)
 
