@@ -4,14 +4,19 @@ Defines utilities to save panel objects to files as HTML or PNG.
 from __future__ import annotations
 
 import io
+import os
 
-from typing import TYPE_CHECKING, Any, Dict, IO, Iterable, List, Optional
+from typing import (
+    IO, TYPE_CHECKING, Any, Dict, Iterable, List, Optional,
+)
 
 import bokeh
 
 from bokeh.document.document import Document
 from bokeh.embed.elements import html_page_for_render_items
-from bokeh.embed.util import OutputDocumentFor, standalone_docs_json_and_render_items
+from bokeh.embed.util import (
+    OutputDocumentFor, standalone_docs_json_and_render_items,
+)
 from bokeh.io.export import get_screenshot_as_png
 from bokeh.model import Model
 from bokeh.resources import CDN, INLINE, Resources as BkResources
@@ -21,8 +26,8 @@ from ..config import config
 from .embed import embed_state
 from .model import add_to_doc
 from .resources import (
-    BASE_TEMPLATE, DEFAULT_TITLE, Bundle, Resources, bundle_resources,
-    set_resource_mode
+    BASE_TEMPLATE, CDN_DIST, DEFAULT_TITLE, Resources, bundle_resources,
+    set_resource_mode,
 )
 from .state import state
 
@@ -148,13 +153,14 @@ def file_html(
     else:
         models_seq = models
 
+    template_variables['dist_url'] = CDN_DIST
+
     with OutputDocumentFor(models_seq, apply_theme=theme, always_new=_always_new):
         (docs_json, render_items) = standalone_docs_json_and_render_items(
             models_seq, suppress_callback_warning=True
         )
         title = _title_from_models(models_seq, title)
         bundle = bundle_resources(models_seq, resources)
-        bundle = Bundle.from_bokeh(bundle)
         return html_page_for_render_items(
             bundle, docs_json, render_items, title=title, template=template,
             template_variables=template_variables
@@ -165,8 +171,8 @@ def file_html(
 #---------------------------------------------------------------------
 
 def save(
-    panel: Viewable, filename: str | IO, title: Optional[str]=None,
-    resources=None, template: Template | str = None,
+    panel: Viewable, filename: str | os.PathLike | IO, title: Optional[str]=None,
+    resources: BkResources | None = None, template: Template | str | None = None,
     template_variables: Dict[str, Any] = None, embed: bool = False,
     max_states: int = 1000, max_opts: int = 3, embed_json: bool = False,
     json_prefix: str = '', save_path: str = './', load_path: Optional[str] = None,
@@ -180,15 +186,15 @@ def save(
     ---------
     panel: Viewable
       The Panel Viewable to save to file
-    filename: string or file-like object
+    filename: str or file-like object
       Filename to save the plot to
-    title: string
+    title: str
       Optional title for the plot
-    resources: bokeh resources
+    resources: bokeh.resources.Resources
       One of the valid bokeh.resources (e.g. CDN or INLINE)
-    template:
+    template: jinja2.Template | str
       template file, as used by bokeh.file_html. If None will use bokeh defaults
-    template_variables:
+    template_variables: Dict[str, Any]
       template_variables file dict, as used by bokeh.file_html
     embed: bool
       Whether the state space should be embedded in the saved file.
@@ -208,7 +214,7 @@ def save(
       Whether to report progress
     embed_states: dict (default={})
       A dictionary specifying the widget values to embed for each widget
-    save_png: boolean (default=None)
+    as_png: boolean (default=None)
         To save as a .png. If None save_png will be true if filename is
         string and ends with png.
     """
