@@ -1,15 +1,15 @@
-import * as p from "@bokehjs/core/properties"
+import type * as p from "@bokehjs/core/properties"
 import {View} from "@bokehjs/core/view"
 import {Model} from "@bokehjs/model"
 
 export class BrowserInfoView extends View {
-  model: BrowserInfo
+  declare model: BrowserInfo
 
-  initialize(): void {
-    super.initialize();
+  override initialize(): void {
+    super.initialize()
 
     if (window.matchMedia != null) {
-      this.model.dark_mode = window.matchMedia('(prefers-color-scheme: dark)').matches
+      this.model.dark_mode = window.matchMedia("(prefers-color-scheme: dark)").matches
     }
     this.model.device_pixel_ratio = window.devicePixelRatio
     if (navigator != null) {
@@ -17,11 +17,13 @@ export class BrowserInfoView extends View {
       this.model.webdriver = navigator.webdriver
     }
     const timezone = Intl.DateTimeFormat().resolvedOptions().timeZone
-    if (timezone != null)
-      this.model.timezone = timezone;
+    if (timezone != null) {
+      this.model.timezone = timezone
+    }
     const timezone_offset = new Date().getTimezoneOffset()
-    if (timezone_offset != null)
-      this.model.timezone_offset = timezone_offset;
+    if (timezone_offset != null) {
+      this.model.timezone_offset = timezone_offset
+    }
     this._has_finished = true
     this.notify_finished()
   }
@@ -42,9 +44,9 @@ export namespace BrowserInfo {
 export interface BrowserInfo extends BrowserInfo.Attrs { }
 
 export class BrowserInfo extends Model {
-  properties: BrowserInfo.Props
+  declare properties: BrowserInfo.Props
 
-  static __module__ = "panel.models.browser"
+  static override __module__ = "panel.models.browser"
 
   constructor(attrs?: Partial<BrowserInfo.Attrs>) {
     super(attrs)
@@ -53,13 +55,13 @@ export class BrowserInfo extends Model {
   static {
     this.prototype.default_view = BrowserInfoView
 
-    this.define<BrowserInfo.Props>(({Boolean, Nullable, Number, String}) => ({
-      dark_mode:          [ Nullable(Boolean), null ],
-      device_pixel_ratio: [ Nullable(Number),  null ],
-      language:           [ Nullable(String),  null ],
-      timezone:           [ Nullable(String),  null ],
-      timezone_offset:    [ Nullable(Number),  null ],
-      webdriver:          [ Nullable(Boolean), null ]
+    this.define<BrowserInfo.Props>(({Bool, Nullable, Float, Str}) => ({
+      dark_mode:          [ Nullable(Bool), null ],
+      device_pixel_ratio: [ Nullable(Float),  null ],
+      language:           [ Nullable(Str),  null ],
+      timezone:           [ Nullable(Str),  null ],
+      timezone_offset:    [ Nullable(Float),  null ],
+      webdriver:          [ Nullable(Bool), null ],
     }))
   }
 }
