@@ -44,25 +44,27 @@ class Plotly(ModelPane):
     >>> Plotly(some_plotly_figure, width=500, height=500)
     """
 
-    click_data = param.Dict(doc="Click callback data")
+    click_data = param.Dict(doc="Click event data from `plotly_click` event.")
 
-    clickannotation_data = param.Dict(doc="Clickannotation callback data")
+    clickannotation_data = param.Dict(doc="Clickannotation event data from `plotly_clickannotation` event.")
 
-    config = param.Dict(nested_refs=True, doc="Config data")
+    config = param.Dict(nested_refs=True, doc="""
+        Plotly configuration options. See https://plotly.com/javascript/configuration-options/""")
 
-    hover_data = param.Dict(doc="Hover callback data")
+    hover_data = param.Dict(doc="Hover event data from `plotly_hover` and `plotly_unhover` events.")
 
     link_figure = param.Boolean(default=True, doc="""
        Attach callbacks to the Plotly figure to update output when it
        is modified in place.""")
 
-    relayout_data = param.Dict(nested_refs=True, doc="Relayout callback data")
+    relayout_data = param.Dict(nested_refs=True, doc="Relayout event data from `plotly_relayout` event")
 
-    restyle_data = param.List(nested_refs=True, doc="Restyle callback data")
+    restyle_data = param.List(nested_refs=True, doc="Restyle event data from `plotly_restyle` event")
 
-    selected_data = param.Dict(nested_refs=True, doc="Selected callback data")
+    selected_data = param.Dict(nested_refs=True, doc="Selected event data from `plotly_selected` and `plotly_deselect` events.")
 
-    viewport = param.Dict(nested_refs=True, doc="Current viewport state")
+    viewport = param.Dict(nested_refs=True, doc="""Current viewport state, i.e. the x- and y-axis limits of the displayed plot.
+                          Updated on `plotly_relayout`, `plotly_relayouting` and `plotly_restyle` events.""")
 
     viewport_update_policy = param.Selector(default="mouseup", doc="""
         Policy by which the viewport parameter is updated during user interactions.
@@ -86,7 +88,8 @@ class Plotly(ModelPane):
     _updates: ClassVar[bool] = True
 
     _rename: ClassVar[Mapping[str, str | None]] = {
-        'link_figure': None, 'object': None
+        'link_figure': None, 'object': None, 'click_data': None, 'clickannotation_data': None,
+        'hover_data': None, 'selected_data': None
     }
 
     @classmethod
@@ -310,7 +313,17 @@ class Plotly(ModelPane):
             self._bokeh_model = lazy_load(
                 'panel.models.plotly', 'PlotlyPlot', isinstance(comm, JupyterComm), root
             )
-        return super()._get_model(doc, root, parent, comm)
+        model = super()._get_model(doc, root, parent, comm)
+        self._register_events('plotly_event', model=model, doc=doc, comm=comm)
+        return model
+
+    def _process_event(self, event):
+        etype = event.data['type']
+        pname = f'{etype}_data'
+        if getattr(self, pname) == event.data['data']:
+            self.param.trigger(pname)
+        else:
+            self.param.update(**{pname: event.data['data']})
 
     def _update(self, ref: str, model: Model) -> None:
         if self.object is None:
