@@ -1,6 +1,7 @@
 """
 A module containing testing utilities and fixtures.
 """
+import asyncio
 import atexit
 import os
 import pathlib
@@ -25,6 +26,9 @@ from pyviz_comms import Comm
 
 from panel import config, serve
 from panel.config import panel_extension
+from panel.io.reload import (
+    _local_modules, _modules, _watched_files, async_file_watcher, watch,
+)
 from panel.io.state import set_curdoc, state
 from panel.pane import HTML, Markdown
 
@@ -149,7 +153,6 @@ PORT = [get_default_port()]
 def document():
     return Document()
 
-
 @pytest.fixture
 def server_document():
     doc = Document()
@@ -157,6 +160,7 @@ def server_document():
     doc._session_context = lambda: session_context
     with set_curdoc(doc):
         yield doc
+    doc._session_context = None
 
 @pytest.fixture
 def bokeh_curdoc():
@@ -174,6 +178,32 @@ def bokeh_curdoc():
 def comm():
     return Comm()
 
+@pytest.fixture
+def stop_event():
+    event = asyncio.Event()
+    try:
+        yield event
+    finally:
+        event.set()
+
+@pytest.fixture
+async def watch_files():
+    tasks = []
+    stop_event = asyncio.Event()
+    def watch_files(*files):
+        watch(*files)
+        tasks.append(asyncio.create_task(async_file_watcher(stop_event)))
+    try:
+        yield watch_files
+    finally:
+        if tasks:
+            try:
+                stop_event.set()
+                await tasks[0]
+            except FileNotFoundError:
+                # Watched files may be deleted before autoreloader
+                # is shut down, therefore we catch the error on deletion.
+                pass
 
 @pytest.fixture
 def port():
@@ -217,6 +247,16 @@ def get_display_handle():
             del state._handles[ref]
 
 
+@pytest.fixture
+def hv_plotly():
+    import holoviews as hv
+    hv.renderer('plotly')
+    prev_backend = hv.Store.current_backend
+    hv.Store.current_backend = 'plotly'
+    yield
+    hv.Store.current_backend = prev_backend
+
+
 @pytest.fixture
 def hv_mpl():
     import holoviews as hv
@@ -345,18 +385,46 @@ def server_cleanup():
         yield
     finally:
         state.reset()
+        _watched_files.clear()
+        _modules.clear()
+        _local_modules.clear()
 
 @pytest.fixture(autouse=True)
 def cache_cleanup():
     state.clear_caches()
 
+@pytest.fixture
+def autoreload():
+    config.autoreload = True
+    def watch(files):
+        if isinstance(files, (str, os.PathLike)):
+            files = [files]
+        _watched_files.update({str(f) for f in files})
+    try:
+        yield watch
+    finally:
+        config.autoreload = False
+
 @pytest.fixture
 def py_file():
-    tf = tempfile.NamedTemporaryFile(mode='w', suffix='.py')
+    tf = tempfile.NamedTemporaryFile(mode='w', suffix='.py', delete=False)
     try:
         yield tf
     finally:
         tf.close()
+        os.unlink(tf.name)
+
+@pytest.fixture
+def py_files():
+    tf = tempfile.NamedTemporaryFile(mode='w', suffix='.py', delete=False)
+    tf2 = tempfile.NamedTemporaryFile(mode='w', suffix='.py', dir=os.path.split(tf.name)[0], delete=False)
+    try:
+        yield tf, tf2
+    finally:
+        tf.close()
+        tf2.close()
+        os.unlink(tf.name)
+        os.unlink(tf2.name)
 
 @pytest.fixture
 def html_file():
