@@ -1,40 +1,26 @@
-import time
-
 import pytest
 
 from panel import Column, GridBox, Spacer
-from panel.io.server import serve
+from panel.tests.util import serve_component, wait_until
 
 pytestmark = pytest.mark.ui
 
-def test_gridbox(page, port):
+def test_gridbox(page):
     grid = GridBox(
         *(Spacer(width=50, height=50) for i in range(12)),
         ncols=4
     )
 
-    serve(grid, port=port, threaded=True, show=False)
+    serve_component(page, grid)
 
-    time.sleep(0.2)
-
-    page.goto(f"http://localhost:{port}")
-
-    bbox = page.locator(".bk-GridBox").bounding_box()
-
-    assert bbox['width'] == 200
-    assert bbox['height'] == 150
+    wait_until(lambda: page.locator(".bk-GridBox").bounding_box() == {'width': 200, 'height': 150, 'x': 0, 'y': 0}, page)
 
     grid.ncols = 6
 
-    time.sleep(0.1)
-
-    bbox = page.locator(".bk-GridBox").bounding_box()
-
-    assert bbox['width'] == 300
-    assert bbox['height'] == 100
+    wait_until(lambda: page.locator(".bk-GridBox").bounding_box() == {'width': 300, 'height': 100, 'x': 0, 'y': 0}, page)
 
 
-def test_gridbox_unequal(page, port):
+def test_gridbox_unequal(page):
     grid = GridBox(
         Spacer(width=50, height=10),
         Spacer(width=40, height=10),
@@ -44,64 +30,28 @@ def test_gridbox_unequal(page, port):
         ncols=4
     )
 
-    serve(grid, port=port, threaded=True, show=False)
+    serve_component(page, grid)
 
-    time.sleep(0.2)
+    wait_until(lambda: page.locator(".bk-GridBox").bounding_box() == {'width': 170, 'height': 50, 'x': 0, 'y': 0}, page)
 
-    page.goto(f"http://localhost:{port}")
-
-    bbox = page.locator(".bk-GridBox").bounding_box()
     children = page.locator(".bk-GridBox div")
-
-    assert bbox['width'] == 170
-    assert bbox['height'] == 50
-    bbox1 = children.nth(0).bounding_box()
-    assert bbox1['x'] == 0
-    assert bbox1['width'] == 50
-    bbox2 = children.nth(1).bounding_box()
-    assert bbox2['x'] == 50
-    assert bbox2['width'] == 40
-    bbox3 = children.nth(2).bounding_box()
-    assert bbox3['x'] == 90
-    assert bbox3['width'] == 60
-    bbox4 = children.nth(3).bounding_box()
-    assert bbox4['x'] == 150
-    assert bbox4['width'] == 20
-    bbox5 = children.nth(4).bounding_box()
-    assert bbox5['x'] == 0
-    assert bbox5['y'] == 20
-    assert bbox5['width'] == 20
-    assert bbox5['height'] == 30
+    wait_until(lambda: children.nth(0).bounding_box() == {'x': 0, 'y': 0, 'width': 50, 'height': 10}, page)
+    wait_until(lambda: children.nth(1).bounding_box() == {'x': 50, 'y': 0, 'width': 40, 'height': 10}, page)
+    wait_until(lambda: children.nth(2).bounding_box() == {'x': 90, 'y': 0, 'width': 60, 'height': 20}, page)
+    wait_until(lambda: children.nth(3).bounding_box() == {'x': 150, 'y': 0, 'width': 20, 'height': 10}, page)
+    wait_until(lambda: children.nth(4).bounding_box() == {'x': 0, 'y': 20, 'width': 20, 'height': 30}, page)
 
     grid.ncols = 5
 
-    time.sleep(0.1)
-
-    bbox = page.locator(".bk-GridBox").bounding_box()
-    children = page.locator(".bk-GridBox div")
-
-    assert bbox['width'] == 190
-    assert bbox['height'] == 30
-    bbox1 = children.nth(0).bounding_box()
-    assert bbox1['x'] == 0
-    assert bbox1['width'] == 50
-    bbox2 = children.nth(1).bounding_box()
-    assert bbox2['x'] == 50
-    assert bbox2['width'] == 40
-    bbox3 = children.nth(2).bounding_box()
-    assert bbox3['x'] == 90
-    assert bbox3['width'] == 60
-    bbox4 = children.nth(3).bounding_box()
-    assert bbox4['x'] == 150
-    assert bbox4['width'] == 20
-    bbox5 = children.nth(4).bounding_box()
-    assert bbox5['x'] == 170
-    assert bbox5['y'] == 0
-    assert bbox5['width'] == 20
-    assert bbox5['height'] == 30
+    wait_until(lambda: page.locator(".bk-GridBox").bounding_box() == {'width': 190, 'height': 30, 'x': 0, 'y': 0}, page)
+    wait_until(lambda: children.nth(0).bounding_box() == {'x': 0, 'y': 0, 'width': 50, 'height': 10}, page)
+    wait_until(lambda: children.nth(1).bounding_box() == {'x': 50, 'y': 0, 'width': 40, 'height': 10}, page)
+    wait_until(lambda: children.nth(2).bounding_box() == {'x': 90, 'y': 0, 'width': 60, 'height': 20}, page)
+    wait_until(lambda: children.nth(3).bounding_box() == {'x': 150, 'y': 0, 'width': 20, 'height': 10}, page)
+    wait_until(lambda: children.nth(4).bounding_box() == {'x': 170, 'y': 0, 'width': 20, 'height': 30}, page)
 
 
-def test_gridbox_stretch_width(page, port):
+def test_gridbox_stretch_width(page):
     grid = Column(GridBox(
         Spacer(sizing_mode='stretch_width', height=50),
         Spacer(sizing_mode='stretch_width', height=50),
@@ -109,11 +59,7 @@ def test_gridbox_stretch_width(page, port):
         ncols=2, sizing_mode='stretch_width'
     ), width=800)
 
-    serve(grid, port=port, threaded=True, show=False)
-
-    time.sleep(0.2)
-
-    page.goto(f"http://localhost:{port}")
+    serve_component(page, grid)
 
     bbox = page.locator(".bk-GridBox").bounding_box()
     children = page.locator(".bk-GridBox div")
@@ -135,7 +81,7 @@ def test_gridbox_stretch_width(page, port):
     assert bbox3['height'] == 50
 
 
-def test_gridbox_stretch_height(page, port):
+def test_gridbox_stretch_height(page):
     grid = Column(GridBox(
         Spacer(sizing_mode='stretch_height', width=50),
         Spacer(sizing_mode='stretch_height', width=50),
@@ -143,11 +89,7 @@ def test_gridbox_stretch_height(page, port):
         ncols=2, sizing_mode='stretch_height'
     ), height=800)
 
-    serve(grid, port=port, threaded=True, show=False)
-
-    time.sleep(0.2)
-
-    page.goto(f"http://localhost:{port}")
+    serve_component(page, grid)
 
     bbox = page.locator(".bk-GridBox").bounding_box()
     children = page.locator(".bk-GridBox div")
@@ -170,7 +112,7 @@ def test_gridbox_stretch_height(page, port):
     assert bbox3['height'] == 400
     assert bbox3['width'] == 50
 
-def test_gridbox_stretch_both(page, port):
+def test_gridbox_stretch_both(page):
     grid = Column(GridBox(
         Spacer(sizing_mode='stretch_both'),
         Spacer(sizing_mode='stretch_both'),
@@ -178,11 +120,7 @@ def test_gridbox_stretch_both(page, port):
         ncols=2, sizing_mode='stretch_both'
     ), height=800, width=600)
 
-    serve(grid, port=port, threaded=True, show=False)
-
-    time.sleep(0.2)
-
-    page.goto(f"http://localhost:{port}")
+    serve_component(page, grid)
 
     bbox = page.locator(".bk-GridBox").bounding_box()
     children = page.locator(".bk-GridBox div")
