@@ -1,3 +1,4 @@
+import asyncio
 import datetime as dt
 
 import numpy as np
@@ -15,7 +16,7 @@ from packaging.version import Version
 from panel.depends import bind
 from panel.io.state import set_curdoc
 from panel.models.tabulator import CellClickEvent, TableEditEvent
-from panel.tests.util import serve_and_request, wait_until
+from panel.tests.util import mpl_available, serve_and_request, wait_until
 from panel.util import BOKEH_JS_NAT
 from panel.widgets import Button, TextInput
 from panel.widgets.tables import DataFrame, Tabulator
@@ -1992,7 +1993,6 @@ def test_server_cell_click_async_event():
 
     counts = []
     async def cb(event, count=[0]):
-        import asyncio
         count[0] += 1
         counts.append(count[0])
         await asyncio.sleep(1)
@@ -2084,6 +2084,54 @@ def test_tabulator_styling_empty_dataframe(document, comm):
         }
     }
 
+
+@mpl_available
+def test_tabulator_style_background_gradient_with_frozen_columns(document, comm):
+    df = pd.DataFrame(np.random.rand(3, 5), columns=list("ABCDE"))
+    table = Tabulator(df, frozen_columns=['A'])
+    table.style.background_gradient(
+        cmap="RdYlGn_r", vmin=0, vmax=0.5, subset=["A", "C", "D"]
+    )
+
+    model = table.get_root(document, comm)
+
+    assert list(model.cell_styles['data'][0]) == [1, 4, 5]
+
+@mpl_available
+def test_tabulator_style_background_gradient_with_frozen_columns_left_and_right(document, comm):
+    df = pd.DataFrame(np.random.rand(3, 5), columns=list("ABCDE"))
+    table = Tabulator(df, frozen_columns={'A': 'left', 'C': 'right'})
+    table.style.background_gradient(
+        cmap="RdYlGn_r", vmin=0, vmax=0.5, subset=["A", "C", "D"]
+    )
+
+    model = table.get_root(document, comm)
+
+    assert list(model.cell_styles['data'][0]) == [1, 6, 4]
+
+@mpl_available
+def test_tabulator_style_background_gradient(document, comm):
+    df = pd.DataFrame(np.random.rand(3, 5), columns=list("ABCDE"))
+    table = Tabulator(df)
+    table.style.background_gradient(
+        cmap="RdYlGn_r", vmin=0, vmax=0.5, subset=["A", "C", "D"]
+    )
+
+    model = table.get_root(document, comm)
+
+    assert list(model.cell_styles['data'][0]) == [2, 4, 5]
+
+@mpl_available
+def test_tabulator_styled_df_with_background_gradient(document, comm):
+    df = pd.DataFrame(np.random.rand(3, 5), columns=list("ABCDE")).style.background_gradient(
+        cmap="RdYlGn_r", vmin=0, vmax=0.5, subset=["A", "C", "D"]
+    )
+    table = Tabulator(df)
+
+    model = table.get_root(document, comm)
+
+    assert list(model.cell_styles['data'][0]) == [2, 4, 5]
+
 def test_tabulator_editor_property_change(dataframe, document, comm):
     editor = SelectEditor(options=['A', 'B', 'C'])
     table = Tabulator(dataframe, editors={'str': editor})
