@@ -7,7 +7,6 @@ from __future__ import annotations
 import itertools
 import re
 
-from collections import OrderedDict
 from types import FunctionType
 from typing import (
     TYPE_CHECKING, Any, ClassVar, Dict, List, Mapping, Type,
@@ -64,8 +63,7 @@ class SelectBase(Widget):
 
     @property
     def _items(self):
-        return OrderedDict(zip(self.labels, self.values))
-
+        return dict(zip(self.labels, self.values))
 
 
 class SingleSelectBase(SelectBase):
@@ -331,12 +329,12 @@ class NestedSelect(CompositeWidget):
     :Example:
 
     >>> NestedSelect(
-            options={
-                "gfs": {"tmp": [1000, 500], "pcp": [1000]},
-                "name": {"tmp": [1000, 925, 850, 700, 500], "pcp": [1000]},
-            },
-            levels=["model", "var", "level"],
-        )
+    ...     options={
+    ...         "gfs": {"tmp": [1000, 500], "pcp": [1000]},
+    ...         "name": {"tmp": [1000, 925, 850, 700, 500], "pcp": [1000]},
+    ...     },
+    ...     levels=["model", "var", "level"],
+    ... )
     """
 
     value = param.Dict(doc="""
@@ -1361,12 +1359,12 @@ class CrossSelector(CompositeWidget, MultiSelect):
         """
         selected = event.obj is self._buttons[True]
 
-        new = OrderedDict([(k, self._items[k]) for k in self._selections[not selected]])
+        new = {k: self._items[k] for k in self._selections[not selected]}
         old = self._lists[selected].options
         other = self._lists[not selected].options
 
-        merged = OrderedDict([(k, k) for k in list(old)+list(new)])
-        leftovers = OrderedDict([(k, k) for k in other if k not in new])
+        merged = {k: k for k in list(old)+list(new)}
+        leftovers = {k: k for k in other if k not in new}
         self._lists[selected].options = merged if merged else {}
         self._lists[not selected].options = leftovers if leftovers else {}
         if len(self._lists[True].options):
