@@ -1051,9 +1051,12 @@ class Tabulator(BaseTable):
         List of client-side filters declared as dictionaries containing
         'field', 'type' and 'value' keys.""")
 
-    frozen_columns = param.List(default=[], nested_refs=True, doc="""
-        List indicating the columns to freeze. The column(s) may be
-        selected by name or index.""")
+    frozen_columns = param.ClassSelector(class_=(list, dict), default=[], nested_refs=True, doc="""
+        One of:
+        - List indicating the columns to freeze. The column(s) may be
+        selected by name or index.
+        - Dict indicating columns to freeze as keys and their freeze location
+        as values, freeze location is either 'right' or 'left'.""")
 
     frozen_rows = param.List(default=[], nested_refs=True, doc="""
         List indicating the rows to freeze. If set, the
@@ -1382,6 +1385,31 @@ class Tabulator(BaseTable):
         if self.pagination == 'remote':
             start = (self.page-1)*self.page_size
             end = start + self.page_size
+
+        # Map column indexes in the data to indexes after frozen_columns are applied
+        column_mapper = {}
+        frozen_cols = self.frozen_columns
+        column_mapper = {}
+        if isinstance(frozen_cols, list):
+            nfrozen = len(frozen_cols)
+            non_frozen = [col for col in df.columns if col not in frozen_cols]
+            for i, col in enumerate(df.columns):
+                if col in frozen_cols:
+                    column_mapper[i] = frozen_cols.index(col) - len(self.indexes)
+                else:
+                    column_mapper[i] = nfrozen + non_frozen.index(col)
+        elif isinstance(frozen_cols, dict):
+            left_cols = [col for col, p in frozen_cols.items() if p in 'left']
+            right_cols = [col for col, p in frozen_cols.items() if p in 'right']
+            non_frozen = [col for col in df.columns if col not in frozen_cols]
+            for i, col in enumerate(df.columns):
+                if col in left_cols:
+                    column_mapper[i] = left_cols.index(col) - len(self.indexes)
+                elif col in right_cols:
+                    column_mapper[i] = len(left_cols) + len(non_frozen) + right_cols.index(col)
+                else:
+                    column_mapper[i] = len(left_cols) + non_frozen.index(col)
+
         styles = {}
         for (r, c), s in styler.ctx.items():
             if self.pagination == 'remote':
@@ -1391,7 +1419,8 @@ class Tabulator(BaseTable):
                     r -= start
             if r not in styles:
                 styles[int(r)] = {}
-            styles[int(r)][offset+int(c)] = s
+            c = column_mapper.get(int(c), int(c))
+            styles[int(r)][offset+c] = s
         return {'id': uuid.uuid4().hex, 'data': styles}
 
     def _get_selectable(self):
@@ -1771,23 +1800,31 @@ class Tabulator(BaseTable):
                 "frozen": True,
                 "width": 40,
             })
-
-        ordered = []
-        for col in self.frozen_columns:
-            if isinstance(col, int):
-                ordered.append(column_objs.pop(col))
-            else:
-                cols = [c for c in column_objs if c.field == col]
-                if cols:
-                    ordered.append(cols[0])
-                    column_objs.remove(cols[0])
-        ordered += column_objs
+        if isinstance(self.frozen_columns, dict):
+            left_frozen_columns = [col for col in column_objs if
+                                   self.frozen_columns.get(col.field, self.frozen_columns.get(column_objs.index(col))) == "left"]
+            right_frozen_columns = [col for col in column_objs if
+                                    self.frozen_columns.get(col.field, self.frozen_columns.get(column_objs.index(col))) == "right"]
+            non_frozen_columns = [col for col in column_objs if
+                                  col.field not in self.frozen_columns and column_objs.index(col) not in self.frozen_columns]
+            ordered_columns = left_frozen_columns + non_frozen_columns + right_frozen_columns
+        else:
+            ordered_columns = []
+            for col in self.frozen_columns:
+                if isinstance(col, int):
+                    ordered_columns.append(column_objs.pop(col))
+                else:
+                    cols = [c for c in column_objs if c.field == col]
+                    if cols:
+                        ordered_columns.append(cols[0])
+                        column_objs.remove(cols[0])
+            ordered_columns += column_objs
 
         grouping = {
             group: [str(gc) for gc in group_cols]
             for group, group_cols in self.groups.items()
         }
-        for i, column in enumerate(ordered):
+        for i, column in enumerate(ordered_columns):
             field = column.field
             matching_groups = [
                 group for group, group_cols in grouping.items()
